==> open-xchange-halo_7.8.2.orig.tar.bz2: open-xchange-halo-7.8.2/com.openexchange.halo/src/com/openexchange/halo/osgi/HaloActivator.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.halo.osgi;

import org.osgi.framework.ServiceReference;
import com.openexchange.config.cascade.ConfigViewFactory;
import com.openexchange.contact.ContactService;
import com.openexchange.halo.ContactHalo;
import com.openexchange.halo.HaloContactDataSource;
import com.openexchange.halo.HaloContactImageSource;
import com.openexchange.halo.contacts.ContactDataSource;
import com.openexchange.halo.internal.ContactHaloImpl;
import com.openexchange.osgi.HousekeepingActivator;
import com.openexchange.osgi.SimpleRegistryListener;
import com.openexchange.session.SessionSpecificContainerRetrievalService;
import com.openexchange.user.UserService;
import com.openexchange.userconf.UserPermissionService;

public class HaloActivator extends HousekeepingActivator {

    @Override
    protected Class<?>[] getNeededServices() {
        return new Class[] { UserService.class, UserPermissionService.class, ContactService.class,
            SessionSpecificContainerRetrievalService.class, ConfigViewFactory.class };
    }

    @Override
    protected void startBundle() throws Exception {
        final ContactHaloImpl halo = new ContactHaloImpl(this);

        ContactDataSource cds = new ContactDataSource(this);
        halo.addContactDataSource(cds);
        halo.addContactImageSource(cds);

        registerService(ContactHalo.class, halo);

        track(HaloContactDataSource.class, new SimpleRegistryListener<HaloContactDataSource>() {

            @Override
            public void added(ServiceReference<HaloContactDataSource> ref, HaloContactDataSource service) {
                halo.addContactDataSource(service);
            }

            @Override
            public void removed(ServiceReference<HaloContactDataSource> ref, HaloContactDataSource service) {
                halo.removeContactDataSource(service);
            }

        });

        track(HaloContactImageSource.class, new SimpleRegistryListener<HaloContactImageSource>() {

            @Override
            public void added(ServiceReference<HaloContactImageSource> ref, HaloContactImageSource service) {
                halo.addContactImageSource(service);
            }

            @Override
            public void removed(ServiceReference<HaloContactImageSource> ref, HaloContactImageSource service) {
                halo.addContactImageSource(service);
            }
        });

        openTrackers();
    }

}

==> open-xchange-halo_7.10.1.orig.tar.bz2: open-xchange-halo-7.10.1/com.openexchange.halo/src/com/openexchange/halo/osgi/HaloActivator.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.halo.osgi;

import org.osgi.framework.ServiceReference;
import com.openexchange.config.cascade.ConfigViewFactory;
import com.openexchange.contact.ContactService;
import com.openexchange.halo.ContactHalo;
import com.openexchange.halo.HaloContactDataSource;
import com.openexchange.halo.HaloContactImageSource;
import com.openexchange.halo.contacts.ContactDataSource;
import com.openexchange.halo.internal.ContactHaloImpl;
import com.openexchange.osgi.HousekeepingActivator;
import com.openexchange.osgi.SimpleRegistryListener;
import com.openexchange.session.SessionSpecificContainerRetrievalService;
import com.openexchange.user.UserService;
import com.openexchange.userconf.UserPermissionService;

public class HaloActivator extends HousekeepingActivator {

    @Override
    protected Class<?>[] getNeededServices() {
        return new Class<?>[] { UserService.class, UserPermissionService.class, ContactService.class,
            SessionSpecificContainerRetrievalService.class, ConfigViewFactory.class };
    }

    @Override
    protected void startBundle() throws Exception {
        final ContactHaloImpl halo = new ContactHaloImpl(this);

        ContactDataSource cds = new ContactDataSource(this);
        halo.addContactDataSource(cds);
        halo.addContactImageSource(cds);

        registerService(ContactHalo.class, halo);

        track(HaloContactDataSource.class, new SimpleRegistryListener<HaloContactDataSource>() {

            @Override
            public void added(ServiceReference<HaloContactDataSource> ref, HaloContactDataSource service) {
                halo.addContactDataSource(service);
            }

            @Override
            public void removed(ServiceReference<HaloContactDataSource> ref, HaloContactDataSource service) {
                halo.removeContactDataSource(service);
            }

        });

        track(HaloContactImageSource.class, new SimpleRegistryListener<HaloContactImageSource>() {

            @Override
            public void added(ServiceReference<HaloContactImageSource> ref, HaloContactImageSource service) {
                halo.addContactImageSource(service);
            }

            @Override
            public void removed(ServiceReference<HaloContactImageSource> ref, HaloContactImageSource service) {
                halo.addContactImageSource(service);
            }
        });

        openTrackers();
    }

}
